<?php
App::uses('AppController', 'Controller');
/**
 * RapportsVisites Controller
 *
 * @property RapportsVisite $RapportsVisite
 */
class RapportsVisitesController extends AppController {

/**
 * index method
 *
 * @return void
 */
public function index() {
	$this->RapportsVisite->recursive = 0;
	$this->set('rapportsVisites', $this->paginate());
}

public function historique(){
	$this->RapportsVisite->recursive = 0;
	$this->set('rapportsVisites', $this->paginate());
}

/**
 * view method
 *
 * @throws NotFoundException
 * @param string $id
 * @return void
 */
public function view($id = null) {
	if (!$this->RapportsVisite->exists($id)) {
		throw new NotFoundException(__('Invalid rapports visite'));
	}
	$options = array('conditions' => array('RapportsVisite.' . $this->RapportsVisite->primaryKey => $id));
	$this->set('rapportsVisite', $this->RapportsVisite->find('first', $options));
}

/**
 * add method
 *
 * @return void
 */
public function add() {

	$this->loadModel('Offrir');
	$this->loadModel('Medicament');
	$this->loadModel('Presentation');

	if ($this->request->is('post')) {
		$this->RapportsVisite->create();
		if ($this->RapportsVisite->saveAll($this->request->data, array('deep' => true))) {
			$this->Session->setFlash(__('The rapports visite has been saved'));
			$this->redirect(array('action' => 'index'));
		} else {
			$this->Session->setFlash(__('The rapports visite could not be saved. Please, try again.'));
		}
	}
	$users = $this->RapportsVisite->User->find('list', array(
		'fields' => 'nom',
		'order' => array('User.nom' => 'ASC'),
		'conditions' => array('User.group_id LIKE' => '1')
		));
	$praticiens = $this->RapportsVisite->Praticien->find('list', array('fields' => 'nom', 'order' => array('Praticien.nom' => 'ASC')));
	$motifs = $this->RapportsVisite->Motif->find('list', array('fields' => 'libelle'));
	$offrirs = $this->RapportsVisite->Offrir->find('list', array('fields' => 'medicament_id'));
	$medicaments = $this->Medicament->find('list', array('fields' => 'id'));

	$this->set(compact('users', 'praticiens', 'motifs', 'offrirs', 'medicaments'));
}

/**
 * edit method
 *
 * @throws NotFoundException
 * @param string $id
 * @return void
 */
public function edit($id = null) {
	if (!$this->RapportsVisite->exists($id)) {
		throw new NotFoundException(__('Invalid rapports visite'));
	}
	if ($this->request->is('post') || $this->request->is('put')) {
		if ($this->RapportsVisite->save($this->request->data)) {
			$this->Session->setFlash(__('The rapports visite has been saved'));
			$this->redirect(array('action' => 'index'));
		} else {
			$this->Session->setFlash(__('The rapports visite could not be saved. Please, try again.'));
		}
	} else {
		$options = array('conditions' => array('RapportsVisite.' . $this->RapportsVisite->primaryKey => $id));
		$this->request->data = $this->RapportsVisite->find('first', $options);
	}
	$users = $this->RapportsVisite->User->find('list');
	$praticiens = $this->RapportsVisite->Praticien->find('list');
	$motifs = $this->RapportsVisite->Motif->find('list');
	$this->set(compact('users', 'praticiens', 'motifs'));
}

/**
 * delete method
 *
 * @throws NotFoundException
 * @throws MethodNotAllowedException
 * @param string $id
 * @return void
 */
public function delete($id = null) {
	$this->RapportsVisite->id = $id;
	if (!$this->RapportsVisite->exists()) {
		throw new NotFoundException(__('Invalid rapports visite'));
	}
	$this->request->onlyAllow('post', 'delete');
	if ($this->RapportsVisite->delete()) {
		$this->Session->setFlash(__('Rapports visite deleted'));
		$this->redirect(array('action' => 'index'));
	}
	$this->Session->setFlash(__('Rapports visite was not deleted'));
	$this->redirect(array('action' => 'index'));
}

public function deleteAll($id = null) {
	$this->loadModel('Presentation');
	$this->loadModel('Offrir');
	$presentations = $this->Presentation->find('all', array(
		'conditions' => array(
			'Presentation.rapports_visite_id' => $id
			)
		));
	foreach($presentations as $presentation){
		$this->Presentation->delete($presentation['Presentation']['id']);
	}
	$echantillons = $this->Offrir->find('all', array(
		'conditions' => array(
			'Offrir.rapports_visite_id' => $id
			)
		));
	foreach($echantillons as $echantillon){
		$this->Offrir->delete($echantillon['Offrir']['id']);
	}
	$this->RapportsVisite->id = $id;
	$options=array('conditions' => array('RapportsVisite.' .$this->RapportsVisite->primaryKey => $id));
	$resultRapport=$this->RapportsVisite->find('first', $options);
	if (!$this->RapportsVisite->exists($id)  || ($resultRapport['RapportsVisite']['user_id'] != $this->Auth->user('id'))) {
		throw new NotFoundException(__('Invalid rapports visite'));
	}
	$this->request->onlyAllow('post', 'delete');
	if ($this->RapportsVisite->delete($id)) {
		$this->Session->setFlash(__('Rapports visite deleted'));
		$this->redirect(array('action' => 'user_historique'));
	}
	$this->Session->setFlash(__('Rapports visite was not deleted'));
	$this->redirect(array('action' => 'index'));
}

}
